@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2012 Yahoo! Inc. All Rights Reserved.
 #    Copyright (C) 2013 Rackspace Hosting All Rights Reserved.
 #
@@ -15,7 +13,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import contextlib
 import copy
 import functools
 import threading
@@ -182,7 +179,7 @@ def _ping_listener(dbapi_conn, connection_rec, connection_proxy):
             raise
 
 
-class _Alchemist(object):
+class _Alchemist:
     """Internal <-> external row <-> objects + other helper functions.
 
     NOTE(harlowja): for internal usage only.
@@ -205,15 +202,17 @@ class _Alchemist(object):
         return atom_cls.from_dict(row)
 
     def atom_query_iter(self, conn, parent_uuid):
-        q = (sql.select([self._tables.atomdetails]).
+        q = (sql.select(self._tables.atomdetails).
              where(self._tables.atomdetails.c.parent_uuid == parent_uuid))
         for row in conn.execute(q):
+            row = row._mapping
             yield self.convert_atom_detail(row)
 
     def flow_query_iter(self, conn, parent_uuid):
-        q = (sql.select([self._tables.flowdetails]).
+        q = (sql.select(self._tables.flowdetails).
              where(self._tables.flowdetails.c.parent_uuid == parent_uuid))
         for row in conn.execute(q):
+            row = row._mapping
             yield self.convert_flow_detail(row)
 
     def populate_book(self, conn, book):
@@ -236,7 +235,7 @@ class SQLAlchemyBackend(base.Backend):
         }
     """
     def __init__(self, conf, engine=None):
-        super(SQLAlchemyBackend, self).__init__(conf)
+        super().__init__(conf)
         if engine is not None:
             self._engine = engine
             self._owns_engine = False
@@ -257,7 +256,6 @@ class SQLAlchemyBackend(base.Backend):
         conf = copy.deepcopy(conf)
         engine_args = {
             'echo': _as_bool(conf.pop('echo', False)),
-            'convert_unicode': _as_bool(conf.pop('convert_unicode', True)),
             'pool_recycle': 3600,
         }
         if 'idle_timeout' in conf:
@@ -385,7 +383,7 @@ class Connection(base.Connection):
             # once it does not mean that we will be able to connect in
             # the future, so this is more of a sanity test and is not
             # complete connection insurance.
-            with contextlib.closing(engine.connect()):
+            with engine.connect():
                 pass
 
         _try_connect(self._engine)
@@ -393,7 +391,7 @@ class Connection(base.Connection):
     def upgrade(self):
         try:
             with self._upgrade_lock:
-                with contextlib.closing(self._engine.connect()) as conn:
+                with self._engine.connect() as conn:
                     # NOTE(imelnikov): Alembic does not support SQLite,
                     # and we don't recommend to use SQLite in production
                     # deployments, so migrations are rarely needed
@@ -401,7 +399,8 @@ class Connection(base.Connection):
                     # SQLite limitations, and create the database directly
                     # from the tables when it is in use...
                     if 'sqlite' in self._engine.url.drivername:
-                        self._metadata.create_all(bind=conn)
+                        with conn.begin():
+                            self._metadata.create_all(bind=conn)
                     else:
                         migration.db_sync(conn)
         except sa_exc.SQLAlchemyError:
@@ -421,12 +420,13 @@ class Connection(base.Connection):
         try:
             atomdetails = self._tables.atomdetails
             with self._engine.begin() as conn:
-                q = (sql.select([atomdetails]).
+                q = (sql.select(atomdetails).
                      where(atomdetails.c.uuid == atom_detail.uuid))
                 row = conn.execute(q).first()
                 if not row:
                     raise exc.NotFound("No atom details found with uuid"
                                        " '%s'" % atom_detail.uuid)
+                row = row._mapping
                 e_ad = self._converter.convert_atom_detail(row)
                 self._update_atom_details(conn, atom_detail, e_ad)
             return e_ad
@@ -438,7 +438,7 @@ class Connection(base.Connection):
     def _insert_flow_details(self, conn, fd, parent_uuid):
         value = fd.to_dict()
         value['parent_uuid'] = parent_uuid
-        conn.execute(sql.insert(self._tables.flowdetails, value))
+        conn.execute(sql.insert(self._tables.flowdetails).values(**value))
         for ad in fd:
             self._insert_atom_details(conn, ad, fd.uuid)
 
@@ -446,7 +446,7 @@ class Connection(base.Connection):
         value = ad.to_dict()
         value['parent_uuid'] = parent_uuid
         value['atom_type'] = models.atom_detail_type(ad)
-        conn.execute(sql.insert(self._tables.atomdetails, value))
+        conn.execute(sql.insert(self._tables.atomdetails).values(**value))
 
     def _update_atom_details(self, conn, ad, e_ad):
         e_ad.merge(ad)
@@ -471,12 +471,13 @@ class Connection(base.Connection):
         try:
             flowdetails = self._tables.flowdetails
             with self._engine.begin() as conn:
-                q = (sql.select([flowdetails]).
+                q = (sql.select(flowdetails).
                      where(flowdetails.c.uuid == flow_detail.uuid))
                 row = conn.execute(q).first()
                 if not row:
                     raise exc.NotFound("No flow details found with"
                                        " uuid '%s'" % flow_detail.uuid)
+                row = row._mapping
                 e_fd = self._converter.convert_flow_detail(row)
                 self._converter.populate_flow_detail(conn, e_fd)
                 self._update_flow_details(conn, flow_detail, e_fd)
@@ -503,10 +504,11 @@ class Connection(base.Connection):
         try:
             logbooks = self._tables.logbooks
             with self._engine.begin() as conn:
-                q = (sql.select([logbooks]).
+                q = (sql.select(logbooks).
                      where(logbooks.c.uuid == book.uuid))
                 row = conn.execute(q).first()
                 if row:
+                    row = row._mapping
                     e_lb = self._converter.convert_book(row)
                     self._converter.populate_book(conn, e_lb)
                     e_lb.merge(book)
@@ -522,7 +524,7 @@ class Connection(base.Connection):
                             self._update_flow_details(conn, fd, e_fd)
                     return e_lb
                 else:
-                    conn.execute(sql.insert(logbooks, book.to_dict()))
+                    conn.execute(sql.insert(logbooks).values(**book.to_dict()))
                     for fd in book:
                         self._insert_flow_details(conn, fd, book.uuid)
                     return book
@@ -534,13 +536,14 @@ class Connection(base.Connection):
     def get_logbook(self, book_uuid, lazy=False):
         try:
             logbooks = self._tables.logbooks
-            with contextlib.closing(self._engine.connect()) as conn:
-                q = (sql.select([logbooks]).
+            with self._engine.connect() as conn:
+                q = (sql.select(logbooks).
                      where(logbooks.c.uuid == book_uuid))
                 row = conn.execute(q).first()
                 if not row:
                     raise exc.NotFound("No logbook found with"
                                        " uuid '%s'" % book_uuid)
+                row = row._mapping
                 book = self._converter.convert_book(row)
                 if not lazy:
                     self._converter.populate_book(conn, book)
@@ -552,9 +555,10 @@ class Connection(base.Connection):
     def get_logbooks(self, lazy=False):
         gathered = []
         try:
-            with contextlib.closing(self._engine.connect()) as conn:
-                q = sql.select([self._tables.logbooks])
+            with self._engine.connect() as conn:
+                q = sql.select(self._tables.logbooks)
                 for row in conn.execute(q):
+                    row = row._mapping
                     book = self._converter.convert_book(row)
                     if not lazy:
                         self._converter.populate_book(conn, book)
@@ -568,7 +572,7 @@ class Connection(base.Connection):
     def get_flows_for_book(self, book_uuid, lazy=False):
         gathered = []
         try:
-            with contextlib.closing(self._engine.connect()) as conn:
+            with self._engine.connect() as conn:
                 for fd in self._converter.flow_query_iter(conn, book_uuid):
                     if not lazy:
                         self._converter.populate_flow_detail(conn, fd)
@@ -577,19 +581,19 @@ class Connection(base.Connection):
             exc.raise_with_cause(exc.StorageFailure,
                                  "Failed getting flow details in"
                                  " logbook '%s'" % book_uuid)
-        for flow_details in gathered:
-            yield flow_details
+        yield from gathered
 
     def get_flow_details(self, fd_uuid, lazy=False):
         try:
             flowdetails = self._tables.flowdetails
             with self._engine.begin() as conn:
-                q = (sql.select([flowdetails]).
+                q = (sql.select(flowdetails).
                      where(flowdetails.c.uuid == fd_uuid))
                 row = conn.execute(q).first()
                 if not row:
                     raise exc.NotFound("No flow details found with uuid"
                                        " '%s'" % fd_uuid)
+                row = row._mapping
                 fd = self._converter.convert_flow_detail(row)
                 if not lazy:
                     self._converter.populate_flow_detail(conn, fd)
@@ -603,12 +607,13 @@ class Connection(base.Connection):
         try:
             atomdetails = self._tables.atomdetails
             with self._engine.begin() as conn:
-                q = (sql.select([atomdetails]).
+                q = (sql.select(atomdetails).
                      where(atomdetails.c.uuid == ad_uuid))
                 row = conn.execute(q).first()
                 if not row:
                     raise exc.NotFound("No atom details found with uuid"
                                        " '%s'" % ad_uuid)
+                row = row._mapping
                 return self._converter.convert_atom_detail(row)
         except sa_exc.SQLAlchemyError:
             exc.raise_with_cause(exc.StorageFailure,
@@ -618,15 +623,14 @@ class Connection(base.Connection):
     def get_atoms_for_flow(self, fd_uuid):
         gathered = []
         try:
-            with contextlib.closing(self._engine.connect()) as conn:
+            with self._engine.connect() as conn:
                 for ad in self._converter.atom_query_iter(conn, fd_uuid):
                     gathered.append(ad)
         except sa_exc.DBAPIError:
             exc.raise_with_cause(exc.StorageFailure,
                                  "Failed getting atom details in flow"
                                  " detail '%s'" % fd_uuid)
-        for atom_details in gathered:
-            yield atom_details
+        yield from gathered
 
     def close(self):
         pass
