@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2014 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -16,8 +14,6 @@
 
 import contextlib
 
-from zake import fake_client
-
 from taskflow.jobs import backends
 from taskflow.jobs.backends import impl_redis
 from taskflow.jobs.backends import impl_zookeeper
@@ -37,18 +33,6 @@ class BackendFetchingTest(test.TestCase):
         with contextlib.closing(backends.fetch('test', conf)) as be:
             self.assertIsInstance(be, impl_zookeeper.ZookeeperJobBoard)
 
-    def test_zk_entry_point_existing_client(self):
-        existing_client = fake_client.FakeClient()
-        conf = {
-            'board': 'zookeeper',
-        }
-        kwargs = {
-            'client': existing_client,
-        }
-        with contextlib.closing(backends.fetch('test', conf, **kwargs)) as be:
-            self.assertIsInstance(be, impl_zookeeper.ZookeeperJobBoard)
-            self.assertIs(existing_client, be._client)
-
     def test_redis_entry_point_text(self):
         conf = 'redis'
         with contextlib.closing(backends.fetch('test', conf)) as be:
