@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2013 Rackspace Hosting All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -25,7 +23,7 @@ from taskflow.tests.unit.persistence import base
 
 class MemoryPersistenceTest(test.TestCase, base.PersistenceTestMixin):
     def setUp(self):
-        super(MemoryPersistenceTest, self).setUp()
+        super().setUp()
         self._backend = impl_memory.MemoryBackend({})
 
     def _get_connection(self):
@@ -35,7 +33,7 @@ class MemoryPersistenceTest(test.TestCase, base.PersistenceTestMixin):
         conn = self._get_connection()
         conn.clear_all()
         self._backend = None
-        super(MemoryPersistenceTest, self).tearDown()
+        super().tearDown()
 
     def test_memory_backend_entry_point(self):
         conf = {'connection': 'memory:'}
@@ -71,26 +69,6 @@ class MemoryFilesystemTest(test.TestCase):
         self.assertEqual('c', fs['/c'])
         self.assertEqual('db', fs['/d/b'])
 
-    def test_old_ls_recursive(self):
-        fs = impl_memory.FakeFilesystem()
-        fs.ensure_path("/d")
-        fs.ensure_path("/c/d")
-        fs.ensure_path("/b/c/d")
-        fs.ensure_path("/a/b/c/d")
-        contents = fs.ls("/", recursive=True)
-        self.assertEqual([
-            '/a',
-            '/b',
-            '/c',
-            '/d',
-            '/a/b',
-            '/b/c',
-            '/c/d',
-            '/a/b/c',
-            '/b/c/d',
-            '/a/b/c/d',
-        ], contents)
-
     def test_ls_recursive(self):
         fs = impl_memory.FakeFilesystem()
         fs.ensure_path("/d")
@@ -140,6 +118,24 @@ class MemoryFilesystemTest(test.TestCase):
         contents = fs.ls_r("/a/b", absolute=False)
         self.assertEqual(['c', 'c/d'], contents)
 
+    def test_ls_targeted(self):
+        fs = impl_memory.FakeFilesystem()
+        fs.ensure_path("/d")
+        fs.ensure_path("/c/d")
+        fs.ensure_path("/b/c/d")
+        fs.ensure_path("/a/b/c/d")
+        contents = fs.ls("/a/b", absolute=False)
+        self.assertEqual(['c'], contents)
+
+    def test_ls_targeted_absolute(self):
+        fs = impl_memory.FakeFilesystem()
+        fs.ensure_path("/d")
+        fs.ensure_path("/c/d")
+        fs.ensure_path("/b/c/d")
+        fs.ensure_path("/a/b/c/d")
+        contents = fs.ls("/a/b", absolute=True)
+        self.assertEqual(['/a/b/c'], contents)
+
     def test_ls_recursive_targeted_absolute(self):
         fs = impl_memory.FakeFilesystem()
         fs.ensure_path("/d")
@@ -149,15 +145,6 @@ class MemoryFilesystemTest(test.TestCase):
         contents = fs.ls_r("/a/b", absolute=True)
         self.assertEqual(['/a/b/c', '/a/b/c/d'], contents)
 
-    def test_old_ls_recursive_targeted_absolute(self):
-        fs = impl_memory.FakeFilesystem()
-        fs.ensure_path("/d")
-        fs.ensure_path("/c/d")
-        fs.ensure_path("/b/c/d")
-        fs.ensure_path("/a/b/c/d")
-        contents = fs.ls("/a/b", recursive=True)
-        self.assertEqual(['/a/b/c', '/a/b/c/d'], contents)
-
     def test_ensure_path(self):
         fs = impl_memory.FakeFilesystem()
         pieces = ['a', 'b', 'c']
