@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2012 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -14,12 +12,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import collections
 import contextlib
 import functools
 import threading
 
 import futurist
-import six
 import testtools
 
 import taskflow.engines
@@ -49,7 +47,42 @@ _EMPTY_TRANSITIONS = [
 ]
 
 
-class EngineTaskTest(object):
+class EngineTaskNotificationsTest:
+    def test_run_capture_task_notifications(self):
+        captured = collections.defaultdict(list)
+
+        def do_capture(bound_name, event_type, details):
+            progress_capture = captured[bound_name]
+            progress_capture.append(details)
+
+        flow = lf.Flow("flow")
+        work_1 = utils.MultiProgressingTask('work-1')
+        work_1.notifier.register(task.EVENT_UPDATE_PROGRESS,
+                                 functools.partial(do_capture, 'work-1'))
+        work_2 = utils.MultiProgressingTask('work-2')
+        work_2.notifier.register(task.EVENT_UPDATE_PROGRESS,
+                                 functools.partial(do_capture, 'work-2'))
+        flow.add(work_1, work_2)
+
+        # NOTE(harlowja): These were selected so that float comparison will
+        # work vs not work...
+        progress_chunks = tuple([0.2, 0.5, 0.8])
+        engine = self._make_engine(
+            flow, store={'progress_chunks': progress_chunks})
+        engine.run()
+
+        expected = [
+            {'progress': 0.0},
+            {'progress': 0.2},
+            {'progress': 0.5},
+            {'progress': 0.8},
+            {'progress': 1.0},
+        ]
+        for name in ['work-1', 'work-2']:
+            self.assertEqual(expected, captured[name])
+
+
+class EngineTaskTest:
 
     def test_run_task_as_flow(self):
         flow = utils.ProgressingTask(name='task1')
@@ -59,7 +92,7 @@ class EngineTaskTest(object):
         expected = ['task1.t RUNNING', 'task1.t SUCCESS(5)']
         self.assertEqual(expected, capturer.values)
 
-    def test_run_task_with_notifications(self):
+    def test_run_task_with_flow_notifications(self):
         flow = utils.ProgressingTask(name='task1')
         engine = self._make_engine(flow)
         with utils.CaptureListener(engine) as capturer:
@@ -68,7 +101,7 @@ class EngineTaskTest(object):
                     'task1.t SUCCESS(5)', 'task1.f SUCCESS']
         self.assertEqual(expected, capturer.values)
 
-    def test_failing_task_with_notifications(self):
+    def test_failing_task_with_flow_notifications(self):
         values = []
         flow = utils.FailingTask('fail')
         engine = self._make_engine(flow)
@@ -198,7 +231,7 @@ class EngineMultipleResultsTest(utils.EngineTestBase):
     def test_many_results_storage_provided_visible_to(self):
         # This works as expected due to docs listed at
         #
-        # http://docs.openstack.org/developer/taskflow/engines.html#scoping
+        # https://docs.openstack.org/taskflow/latest/user/engines.html#scoping
         flow = lf.Flow("flow")
         flow.add(utils.AddOneSameProvidesRequires('a'))
         flow.add(utils.AddOneSameProvidesRequires('b'))
@@ -301,6 +334,36 @@ class EngineLinearFlowTest(utils.EngineTestBase):
         results = engine.storage.fetch_all()
         self.assertEqual(2, results['result'])
 
+    def test_sequential_flow_interrupted_externally(self):
+        flow = lf.Flow('flow-1').add(
+            utils.ProgressingTask(name='task1'),
+            utils.ProgressingTask(name='task2'),
+            utils.ProgressingTask(name='task3'),
+        )
+        engine = self._make_engine(flow)
+
+        def _run_engine_and_raise():
+            engine_states = {}
+            engine_it = engine.run_iter()
+            while True:
+                try:
+                    engine_state = next(engine_it)
+                    if engine_state not in engine_states:
+                        engine_states[engine_state] = 1
+                    else:
+                        engine_states[engine_state] += 1
+                    if engine_states.get(states.SCHEDULING) == 2:
+                        engine_state = engine_it.throw(IOError("I Broke"))
+                        if engine_state not in engine_states:
+                            engine_states[engine_state] = 1
+                        else:
+                            engine_states[engine_state] += 1
+                except StopIteration:
+                    break
+
+        self.assertRaises(IOError, _run_engine_and_raise)
+        self.assertEqual(states.FAILURE, engine.storage.get_flow_state())
+
     def test_sequential_flow_one_task(self):
         flow = lf.Flow('flow-1').add(
             utils.ProgressingTask(name='task1')
@@ -332,7 +395,7 @@ class EngineLinearFlowTest(utils.EngineTestBase):
         engine = self._make_engine(flow)
         with utils.CaptureListener(engine, capture_flow=False) as capturer:
             gathered_states = list(engine.run_iter())
-        self.assertTrue(len(gathered_states) > 0)
+        self.assertGreater(len(gathered_states), 0)
         expected = ['task1.t RUNNING', 'task1.t SUCCESS(5)',
                     'task2.t RUNNING', 'task2.t SUCCESS(5)']
         self.assertEqual(expected, capturer.values)
@@ -359,7 +422,7 @@ class EngineLinearFlowTest(utils.EngineTestBase):
                         suspend_it = True
                 except StopIteration:
                     break
-        self.assertTrue(len(gathered_states) > 0)
+        self.assertGreater(len(gathered_states), 0)
         expected = ['task1.t RUNNING', 'task1.t SUCCESS(5)']
         self.assertEqual(expected, capturer.values)
         self.assertEqual(states.SUSPENDED, engine.storage.get_flow_state())
@@ -367,7 +430,7 @@ class EngineLinearFlowTest(utils.EngineTestBase):
         # Attempt to resume it and see what runs now...
         with utils.CaptureListener(engine, capture_flow=False) as capturer:
             gathered_states = list(engine.run_iter())
-        self.assertTrue(len(gathered_states) > 0)
+        self.assertGreater(len(gathered_states), 0)
         expected = ['task2.t RUNNING', 'task2.t SUCCESS(5)']
         self.assertEqual(expected, capturer.values)
         self.assertEqual(states.SUCCESS, engine.storage.get_flow_state())
@@ -513,8 +576,8 @@ class EngineParallelFlowTest(utils.EngineTestBase):
         engine = self._make_engine(flow)
         with utils.CaptureListener(engine, capture_flow=False) as capturer:
             engine.run()
-        expected = set(['task2.t SUCCESS(5)', 'task2.t RUNNING',
-                        'task1.t RUNNING', 'task1.t SUCCESS(5)'])
+        expected = {'task2.t SUCCESS(5)', 'task2.t RUNNING',
+                    'task1.t RUNNING', 'task1.t SUCCESS(5)'}
         self.assertEqual(expected, set(capturer.values))
 
     def test_parallel_revert(self):
@@ -569,6 +632,20 @@ class EngineParallelFlowTest(utils.EngineTestBase):
         self.assertEqual({'x1': 17, 'x2': 5},
                          engine.storage.fetch_all())
 
+    # Reproducer for #2139228 and #2086453
+    def test_many_unordered_flows_in_linear_flow(self):
+        flow = lf.Flow("root")
+        for i in range(10):
+            sf = uf.Flow(f'subflow {i}')
+            for j in range(10):
+                sf.add(utils.ProgressingTask(name=f"task {i}:{j}"))
+            flow.add(sf)
+
+        engine = self._make_engine(flow)
+        with utils.CaptureListener(engine, capture_flow=False) as capturer:
+            engine.run()
+            self.assertIn("task 9:9.t SUCCESS(5)", capturer.values)
+
 
 class EngineLinearAndUnorderedExceptionsTest(utils.EngineTestBase):
 
@@ -788,8 +865,8 @@ class EngineGraphFlowTest(utils.EngineTestBase):
         engine = self._make_engine(flow)
         with utils.CaptureListener(engine, capture_flow=False) as capturer:
             engine.run()
-        expected = set(['task2.t SUCCESS(5)', 'task2.t RUNNING',
-                        'task1.t RUNNING', 'task1.t SUCCESS(5)'])
+        expected = {'task2.t SUCCESS(5)', 'task2.t RUNNING',
+                    'task1.t RUNNING', 'task1.t SUCCESS(5)'}
         self.assertEqual(expected, set(capturer.values))
         self.assertEqual(2, len(flow))
 
@@ -1153,7 +1230,7 @@ class EngineGraphConditionalFlowTest(utils.EngineTestBase):
         with utils.CaptureListener(engine, capture_flow=False) as capturer:
             engine.run()
 
-        expected = set([
+        expected = {
             'task1.t RUNNING',
             'task1.t SUCCESS(5)',
 
@@ -1162,7 +1239,7 @@ class EngineGraphConditionalFlowTest(utils.EngineTestBase):
 
             'task3.t RUNNING',
             'task3.t SUCCESS(5)',
-        ])
+        }
         self.assertEqual(expected, set(capturer.values))
 
     def test_graph_flow_conditional_ignore_reset(self):
@@ -1181,7 +1258,7 @@ class EngineGraphConditionalFlowTest(utils.EngineTestBase):
         with utils.CaptureListener(engine, capture_flow=False) as capturer:
             engine.run()
 
-        expected = set([
+        expected = {
             'task1.t RUNNING',
             'task1.t SUCCESS(5)',
 
@@ -1189,7 +1266,7 @@ class EngineGraphConditionalFlowTest(utils.EngineTestBase):
             'task2.t SUCCESS(5)',
 
             'task3.t IGNORE',
-        ])
+        }
         self.assertEqual(expected, set(capturer.values))
         self.assertEqual(states.IGNORE,
                          engine.storage.get_atom_state('task3'))
@@ -1201,7 +1278,7 @@ class EngineGraphConditionalFlowTest(utils.EngineTestBase):
         with utils.CaptureListener(engine, capture_flow=False) as capturer:
             engine.run()
 
-        expected = set([
+        expected = {
             'task1.t RUNNING',
             'task1.t SUCCESS(5)',
 
@@ -1210,7 +1287,7 @@ class EngineGraphConditionalFlowTest(utils.EngineTestBase):
 
             'task3.t RUNNING',
             'task3.t SUCCESS(5)',
-        ])
+        }
         self.assertEqual(expected, set(capturer.values))
 
     def test_graph_flow_diamond_ignored(self):
@@ -1231,7 +1308,7 @@ class EngineGraphConditionalFlowTest(utils.EngineTestBase):
         with utils.CaptureListener(engine, capture_flow=False) as capturer:
             engine.run()
 
-        expected = set([
+        expected = {
             'task1.t RUNNING',
             'task1.t SUCCESS(5)',
 
@@ -1242,7 +1319,7 @@ class EngineGraphConditionalFlowTest(utils.EngineTestBase):
             'task3.t SUCCESS(5)',
 
             'task4.t IGNORE',
-        ])
+        }
         self.assertEqual(expected, set(capturer.values))
         self.assertEqual(states.IGNORE,
                          engine.storage.get_atom_state('task4'))
@@ -1252,7 +1329,7 @@ class EngineGraphConditionalFlowTest(utils.EngineTestBase):
     def test_graph_flow_conditional_history(self):
 
         def even_odd_decider(history, allowed):
-            total = sum(six.itervalues(history))
+            total = sum(history.values())
             if total == allowed:
                 return True
             return False
@@ -1280,12 +1357,12 @@ class EngineGraphConditionalFlowTest(utils.EngineTestBase):
         with utils.CaptureListener(engine, capture_flow=False) as capturer:
             engine.run()
 
-        expected = set([
+        expected = {
             'task1.t RUNNING', 'task1.t SUCCESS(2)',
             'task3.t IGNORE', 'task3_3.t IGNORE',
             'task2.t RUNNING', 'task2.t SUCCESS(5)',
             'task2_2.t RUNNING', 'task2_2.t SUCCESS(5)',
-        ])
+        }
         self.assertEqual(expected, set(capturer.values))
 
         engine = self._make_engine(flow)
@@ -1293,12 +1370,12 @@ class EngineGraphConditionalFlowTest(utils.EngineTestBase):
         with utils.CaptureListener(engine, capture_flow=False) as capturer:
             engine.run()
 
-        expected = set([
+        expected = {
             'task1.t RUNNING', 'task1.t SUCCESS(1)',
             'task2.t IGNORE', 'task2_2.t IGNORE',
             'task3.t RUNNING', 'task3.t SUCCESS(5)',
             'task3_3.t RUNNING', 'task3_3.t SUCCESS(5)',
-        ])
+        }
         self.assertEqual(expected, set(capturer.values))
 
 
@@ -1324,7 +1401,7 @@ class EngineCheckingTaskTest(utils.EngineTestBase):
             utils.FailingTask('fail1')
         )
         engine = self._make_engine(flow)
-        self.assertRaisesRegexp(RuntimeError, '^Woot', engine.run)
+        self.assertRaisesRegex(RuntimeError, '^Woot', engine.run)
 
 
 class SerialEngineTest(EngineTaskTest,
@@ -1339,6 +1416,7 @@ class SerialEngineTest(EngineTaskTest,
                        EngineGraphConditionalFlowTest,
                        EngineCheckingTaskTest,
                        EngineDeciderDepthTest,
+                       EngineTaskNotificationsTest,
                        test.TestCase):
     def _make_engine(self, flow,
                      flow_detail=None, store=None, **kwargs):
@@ -1369,6 +1447,7 @@ class ParallelEngineWithThreadsTest(EngineTaskTest,
                                     EngineGraphConditionalFlowTest,
                                     EngineCheckingTaskTest,
                                     EngineDeciderDepthTest,
+                                    EngineTaskNotificationsTest,
                                     test.TestCase):
     _EXECUTOR_WORKERS = 2
 
@@ -1413,52 +1492,20 @@ class ParallelEngineWithEventletTest(EngineTaskTest,
                                      EngineGraphConditionalFlowTest,
                                      EngineCheckingTaskTest,
                                      EngineDeciderDepthTest,
+                                     EngineTaskNotificationsTest,
                                      test.TestCase):
 
     def _make_engine(self, flow,
                      flow_detail=None, executor=None, store=None,
                      **kwargs):
         if executor is None:
-            executor = futurist.GreenThreadPoolExecutor()
-            self.addCleanup(executor.shutdown)
+            executor = 'greenthreads'
         return taskflow.engines.load(flow, flow_detail=flow_detail,
                                      backend=self.backend, engine='parallel',
                                      executor=executor,
                                      store=store, **kwargs)
 
 
-class ParallelEngineWithProcessTest(EngineTaskTest,
-                                    EngineMultipleResultsTest,
-                                    EngineLinearFlowTest,
-                                    EngineParallelFlowTest,
-                                    EngineLinearAndUnorderedExceptionsTest,
-                                    EngineOptionalRequirementsTest,
-                                    EngineGraphFlowTest,
-                                    EngineResetTests,
-                                    EngineMissingDepsTest,
-                                    EngineGraphConditionalFlowTest,
-                                    EngineDeciderDepthTest,
-                                    test.TestCase):
-    _EXECUTOR_WORKERS = 2
-
-    def test_correct_load(self):
-        engine = self._make_engine(utils.TaskNoRequiresNoReturns)
-        self.assertIsInstance(engine, eng.ParallelActionEngine)
-
-    def _make_engine(self, flow,
-                     flow_detail=None, executor=None, store=None,
-                     **kwargs):
-        if executor is None:
-            executor = 'processes'
-        return taskflow.engines.load(flow, flow_detail=flow_detail,
-                                     backend=self.backend,
-                                     engine='parallel',
-                                     executor=executor,
-                                     store=store,
-                                     max_workers=self._EXECUTOR_WORKERS,
-                                     **kwargs)
-
-
 class WorkerBasedEngineTest(EngineTaskTest,
                             EngineMultipleResultsTest,
                             EngineLinearFlowTest,
@@ -1470,9 +1517,10 @@ class WorkerBasedEngineTest(EngineTaskTest,
                             EngineMissingDepsTest,
                             EngineGraphConditionalFlowTest,
                             EngineDeciderDepthTest,
+                            EngineTaskNotificationsTest,
                             test.TestCase):
     def setUp(self):
-        super(WorkerBasedEngineTest, self).setUp()
+        super().setUp()
         shared_conf = {
             'exchange': 'test',
             'transport': 'memory',
