@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2012-2013 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -24,7 +22,7 @@ def add(a, b):
     return a + b
 
 
-class BunchOfFunctions(object):
+class BunchOfFunctions:
 
     def __init__(self, values):
         self.values = values
@@ -65,8 +63,8 @@ class FunctorTaskTest(test.TestCase):
             t(bof.run_one, revert=bof.revert_one),
             t(bof.run_fail)
         )
-        self.assertRaisesRegexp(RuntimeError, '^Woot',
-                                taskflow.engines.run, flow)
+        self.assertRaisesRegex(RuntimeError, '^Woot',
+                               taskflow.engines.run, flow)
         self.assertEqual(['one', 'fail', 'revert one'], values)
 
     def test_lambda_functors(self):
@@ -91,4 +89,4 @@ class FunctorTaskTest(test.TestCase):
             'product': 6
         })
 
-        self.assertDictEqual(expected, result)
+        self.assertEqual(expected, result)
