@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2014 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -25,6 +23,10 @@ from taskflow.tests import utils
 from taskflow.types import failure
 
 
+class Unserializable:
+    pass
+
+
 class TestProtocolValidation(test.TestCase):
     def test_send_notify(self):
         msg = pr.Notify()
@@ -94,7 +96,7 @@ class TestProtocolValidation(test.TestCase):
 class TestProtocol(test.TestCase):
 
     def setUp(self):
-        super(TestProtocol, self).setUp()
+        super().setUp()
         self.task = utils.DummyTask()
         self.task_uuid = 'task-uuid'
         self.task_action = 'execute'
@@ -121,8 +123,8 @@ class TestProtocol(test.TestCase):
 
     def test_request_transitions(self):
         request = self.request()
-        self.assertEqual(pr.WAITING, request.state)
-        self.assertIn(request.state, pr.WAITING_STATES)
+        self.assertEqual(pr.WAITING, request.current_state)
+        self.assertIn(request.current_state, pr.WAITING_STATES)
         self.assertRaises(excp.InvalidState, request.transition, pr.SUCCESS)
         self.assertFalse(request.transition(pr.WAITING))
         self.assertTrue(request.transition(pr.PENDING))
@@ -166,7 +168,7 @@ class TestProtocol(test.TestCase):
         self.assertEqual(expected, request.to_dict())
 
     def test_to_dict_with_invalid_json_failures(self):
-        exc = RuntimeError(Exception("I am not valid JSON"))
+        exc = RuntimeError(Unserializable())
         a_failure = failure.Failure.from_exception(exc)
         request = self.request(failures={self.task.name: a_failure})
         expected = self.request_to_dict(
